yarp_trafficGen {#master}
-------------------------

## Important Changes

### Yarp companion

#### added command `yarp trafficGen`
* `yarp trafficGen` sends generated data over a yarp port. The tool allows to test the communication and the available bandwidth over the network.
